aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--tests/hazmat/bindings/test_openssl.py19
1 files changed, 12 insertions, 7 deletions
diff --git a/tests/hazmat/bindings/test_openssl.py b/tests/hazmat/bindings/test_openssl.py
index 3523fa4e..4e8dfa58 100644
--- a/tests/hazmat/bindings/test_openssl.py
+++ b/tests/hazmat/bindings/test_openssl.py
@@ -11,15 +11,21 @@
# See the License for the specific language governing permissions and
# limitations under the License.
-import binascii
-
import pytest
from cryptography.exceptions import UnsupportedAlgorithm
from cryptography.hazmat.bindings.openssl.backend import backend, Backend
from cryptography.hazmat.primitives.block import BlockCipher
-from cryptography.hazmat.primitives.block.ciphers import AES, TripleDES
-from cryptography.hazmat.primitives.block.modes import CBC, ECB
+from cryptography.hazmat.primitives.block.ciphers import AES
+from cryptography.hazmat.primitives.block.modes import CBC
+
+
+class FakeMode(object):
+ pass
+
+
+class FakeCipher(object):
+ pass
class TestOpenSSL(object):
@@ -51,12 +57,11 @@ class TestOpenSSL(object):
def test_nonexistent_cipher(self):
b = Backend()
- # TODO: this test assumes that 3DES-ECB doesn't exist
b.ciphers.register_cipher_adapter(
TripleDES, ECB, lambda backend, cipher, mode: backend.ffi.NULL
)
cipher = BlockCipher(
- TripleDES(binascii.unhexlify(b"0" * 16)), ECB(), backend=b
+ FakeCipher(), FakeMode(), backend=b,
)
with pytest.raises(UnsupportedAlgorithm):
cipher.encryptor()
@@ -51,12 +57,11 @@ class TestOpenSSL(object):
b.ciphers.register_cipher_adapter(
- TripleDES, ECB, lambda backend, cipher, mode: backend.ffi.NULL
+ FakeCipher, FakeMode, lambda backend, cipher, mode: backend.ffi.NULL
)
cipher = BlockCipher(